# To Do until Package is complete

- [x] Fully document
	- [x] base_objects.py
	- [x] conditions.py
	- [x] dorst_motions.py
	- [x] four_quaternions.py
	- [x] geom_generators.py
	- [ ] multivector.py
	- [x] operators.py
	- [x] random.py
- [ ] Maybe document helper functions
- [ ] Write README
- [x] Write User Guide
- [ ] implement sphinx
